/**
 * La classe d'une tâche planifiée.
 *
 * @class
 */
export default class At {
    /**
     * Crée une tâche planifiée.
     *
     * @param {Date}     date              La date de planification de la tâche.
     * @param {Function} func              La fonction appelée à la date
     *                                     planifiée.
     * @param {Object}   [options]         Les options de la planification de la
     *                                     tâche.
     * @param {any}      [options.thisArg] Le <code>this</code> utilisé pour la
     *                                     fonction (la tâche planifiée par
     *                                     défaut).
     * @param {any[]}    [options.args]    Les paramètres passés à la fonction
     *                                     (aucun paramètre par défaut).
     * @throws {TypeError} Si le constructeur est appelé sans le mot clé
     *                     <code>new</code>.
     */
    constructor(date: Date, func: Function, options?: {
        thisArg?: any;
        args?: any[];
    });
    /**
     * Exécute manuellement la fonction.
     */
    run(): void;
    /**
     * Annule la planification.
     */
    abort(): void;
    #private;
}
