/**
 * La classe d'une expression <em>cron</em>.
 *
 * @class
 */
export default class CronExp {
    /**
     * Crée une expression <em>cron</em>.
     *
     * @param {string} pattern Le motif de l'expression <em>cron</em>.
     * @throws {Error}      Si la syntaxe du motif est incorrecte.
     * @throws {RangeError} Si un intervalle est invalide (hors limite ou quand
     *                      la borne supérieure est plus petite que la borne
     *                      inférieure).
     * @throws {TypeError}  Si le constructeur est appelé sans le mot clé
     *                      <code>new</code> ou si le motif n'est pas une chaine
     *                      de caractères.
     */
    constructor(pattern: string);
    /**
     * Teste si une date respecte l'expression.
     *
     * @param {Date} [date] La date qui sera testée (ou l'instant présent par
     *                      défaut).
     * @returns {boolean} <code>true</code> si l'expression est respectée ;
     *                    sinon <code>false</code>.
     */
    test(date?: Date): boolean;
    /**
     * Calcule la prochaine date respectant l'expression.
     *
     * @param {Date} [start] La date de début (ou l'instant présent par défaut).
     * @returns {Date} La prochaine date respectant l'expression.
     */
    next(start?: Date): Date;
    #private;
}
